import { extent, scaleLinear, scaleLog, scaleOrdinal, schemeCategory10 } from 'd3';
import { axes } from './axes';
import { colorLegend } from './colorLegend';

export const scatterPlot = (
  selection,
  { data, 
   	width,
   	height, 
   	xValue, 
   	yValue, 
    colorValue,
   	xAxisLabel, 
   	yAxisLabel, 
   	margin,
    colorLegendLabel,
    colorLegendX,
    colorLegendY, 
  }
) => {
  const xScale = scaleLog()
    .domain([30000, 9000000])
    .range([margin.left, width - margin.right]);

  const yScale = scaleLinear()
  	.domain([5000, 260000])
    .range([height - margin.bottom, margin.top]);
  
    const colorScale = scaleOrdinal()
    .domain(data.map(colorValue))
    .range(schemeCategory10);
  
  // var color = scaleOrdinal()
  //   .domain(["English", "Portuguese", "Spanish", "Korean"])
  //   .range([ "#D0270399", "#21908d99", "#fde72599", "#0920E999"])
  
  selection.call(axes, {
    xScale,
    yScale,
    xAxisLabel,
    yAxisLabel,
  });
  
  selection.call(colorLegend, {
    colorScale,
    colorLegendLabel,
    colorLegendX,
    colorLegendY,
  });

  selection
    .selectAll('circle.mark')
    .data(data)
    .join('circle')
    .attr('cx', (d) => xScale(xValue(d)))
    .attr('cy', (d) => yScale(yValue(d)))
  	.attr('fill', (d) =>
      colorScale(colorValue(d))
    )
    .attr('r', 8)
  	.attr('fill-opacity', 0.6);
};
